%define anolis_release 1

Name:		libssh2
Version:	1.11.0
Release:	%{anolis_release}%{?dist}
Summary:	A library implementing the SSH2 protocol
License:	BSD
URL:		https://www.libssh2.org/

Source0:	https://libssh2.org/download/libssh2-%{version}.tar.xz
Source1:	https://libssh2.org/download/libssh2-%{version}.tar.xz.asc
# Daniel Stenberg's GPG keys; linked from https://daniel.haxx.se/address.html
Source2:	https://daniel.haxx.se/mykey.asc

Patch0000:	0000-PATCH-libssh2-1.11.0-strict-modes.patch
Patch0001:	0001-PATCH-libssh2-1.11.0-ssh-rsa-test.patch

BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	gnupg2
BuildRequires:	make
BuildRequires:	openssl-devel > 1:1.0.1
BuildRequires:	sed
BuildRequires:	zlib-devel
BuildRequires:	/usr/bin/man

# Test suite requirements
# Full groff (not just groff-base) needed for the mansyntax check
BuildRequires:	groff
# We run the OpenSSH server and try to connect to it
BuildRequires:	openssh-server
# Need a valid locale to run the mansyntax check
BuildRequires:	glibc-langpack-en

%description
libssh2 is a library implementing the SSH2 protocol as defined by
Internet Drafts: SECSH-TRANS(22), SECSH-USERAUTH(25),
SECSH-CONNECTION(23), SECSH-ARCH(20), SECSH-FILEXFER(06)*,
SECSH-DHGEX(04), and SECSH-NUMBERS(10).

%package	devel
Summary:	Development files for libssh2
Requires:	%{name} = %{version}-%{release}

%description	devel
The libssh2-devel package contains libraries and header files for
developing applications that use libssh2.

%package	docs
Summary:	Documentation for libssh2
Requires:	%{name} = %{version}-%{release}
BuildArch:	noarch

%description	docs
The libssh2-docs package contains man pages and examples for
developing applications that use libssh2.

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -n %{name}-%{version} -p0

# Replace hard wired port number in the test suite to avoid collisions
# between 32-bit and 64-bit builds running on a single build-host
sed -i s/4711/47%{?__isa_bits}/ tests/{openssh_fixture.c,test_ssh{2.c,d.test}}

%build
%configure --disable-silent-rules --enable-shared --disable-docker-tests
%{make_build}

%install
%{make_install} INSTALL="install -p"

# Remove static library that we only built for testing
rm -v %{buildroot}%{_libdir}/libssh2.a

# clean things up a bit for packaging
make -C example clean
rm -rf example/.deps
find example/ -type f '(' -name '*.am' -o -name '*.in' ')' -delete

# Remove redundant references to libdir in pkg-config file
sed -i	-e 's|-L%{_libdir} ||g' \
	-e 's|-L[$]{libdir} ||g' %{buildroot}%{_libdir}/pkgconfig/libssh2.pc

# avoid multilib conflict on libssh2-devel
mv -v example example.%{_arch}

%generate_compatibility_deps

%check
LC_ALL=en_US.UTF-8 make -C tests check

%files
%dir %{abidir}
%license COPYING
%{_libdir}/libssh2.so.1
%{_libdir}/libssh2.so.1.*
%{abidir}/libssh2.dump

%files docs
%doc docs/BINDINGS.md docs/HACKING.md docs/TODO NEWS
%{_mandir}/man3/libssh2_*.3*

%files devel
%doc example.%{_arch}/
%{_includedir}/libssh2.h
%{_includedir}/libssh2_publickey.h
%{_includedir}/libssh2_sftp.h
%{_libdir}/libssh2.so
%{_libdir}/pkgconfig/libssh2.pc

%changelog
* Tue Jul 11 2023 Funda Wang <fundawang@yeah.net> - 1.11.0-1
- New version 1.11.0

* Tue Feb 14 2023 Guyu Wang <guyu.wgy@linux.alibaba.com> - 1.10.0-2
- Verify upstream release signatures

* Tue Jul 12 2022 happy_orange <songnannan@linux.alibaba.com> - 1.10.0-1
- Init pcakage from upstream
